//
//  PDFView.m
//  PDFReader
//
//  Created by KUDO IKUO on 12/06/23.
//  Copyright (c) 2012年 n/a. All rights reserved.
//

#import "PDFView.h"
#import <QuartzCore/QuartzCore.h>

@interface PDFView ()
- ( void ) setup;
@end

@implementation PDFView
@synthesize scale;
@synthesize image;

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [ self setup ];
    }
    return self;
}

+ ( Class ) layerClass 
{
    return [ CATiledLayer class ];
}

- ( void ) setup
{
    scale = 1.0;
    self.contentScaleFactor = 1.0;
    
    CATiledLayer* tile = ( CATiledLayer* ) self.layer;
    tile.levelsOfDetail = 4;
    tile.levelsOfDetailBias = 4;
    tile.tileSize = CGSizeMake( 512.0, 512.0 );
}

- ( void ) setImage:(UIImage *)aImage
{
    self.image = aImage;
    [ self setNeedsDisplay ];
}

- (void)drawRect:(CGRect)rect {
    
    if( !self.image ) return;
    
    // 現在のグラフィックスコンテキストを取得する
	CGContextRef context = UIGraphicsGetCurrentContext();
    // グラフィックスコンテキストからアフィン変換行列を取得する
    CGAffineTransform transform = CGContextGetCTM(context);
	
    // 表示領域の左端の x 座標を求める
    int xmin = CGRectGetMinX(rect);
    // 表示領域の上端の y 座標を求める
    int ymin = CGRectGetMinY(rect);
    // 表示領域の右端の x 座標を求める 
    int xmax = CGRectGetMaxX(rect);
    // 表示領域の下端の y 座標を求める
    int ymax = CGRectGetMaxY(rect); 
    // 左端の x 座標を表示領域の幅で割り、ヨコの何分割目かをもとめる 
    int x = xmin / CGRectGetWidth(rect);
    // 上端の y 座標を表示領域の高さで割り、タテの何分割目かをもとめる
    int y = ymin / CGRectGetHeight(rect);  
	
    // transform.a は拡大率
	NSLog(@"%@", 
          [NSString stringWithFormat:@"%gx [%d,%d] (%d,%d)-(%d,%d)", transform.a, x, y, xmin, ymin, xmax, ymax]);
	
    // 表示領域に合う画像を読み込む
	    // 描画
    
	[ self.image drawInRect:rect];
}

@end
